@@ -23,18 +23,19 @@
 #define SIDBANK_H
 
 #include "Bank.h"
-#include "sidplayfp/c64/c64sid.h"
+#include "c64/c64sid.h"
 
 #include "NullSid.h"
 
 /**
-* SID
-* located at $D400-$D7FF, mirrored each 32 bytes
-*/
+ * SID
+ *
+ * Located at $D400-$D7FF, mirrored each 32 bytes
+ */
 class SidBank : public Bank
 {
 private:
-    /** SID chip */
+    /// SID chip
     c64sid *sid;
 
 public:
@@ -58,10 +59,10 @@ public:
     }
 
     /**
-    * Set SID emulation.
-    *
-    * @param s the emulation
-    */
+     * Set SID emulation.
+     *
+     * @param s the emulation
+     */
     void setSID(c64sid *s) { sid = (s != 0) ? s : NullSid::getInstance(); }
 };
 
