@@ -1,7 +1,7 @@
 /*
  * This file is part of libsidplayfp, a SID player engine.
  *
- * Copyright 2011-2013 Leandro Nini <drfiemost@users.sourceforge.net>
+ * Copyright 2011-2018 Leandro Nini <drfiemost@users.sourceforge.net>
  * Copyright 2007-2010 Antti Lankila
  * Copyright 2001 Simon White
  *
@@ -31,6 +31,10 @@
 #include "sidendian.h"
 #include "VIC_II/mos656x.h"
 
+#ifdef DEBUG
+#  include <iostream>
+#endif
+
 /**
  * VIC-II
  *
@@ -59,6 +63,23 @@ public:
 
     void poke(uint_least16_t address, uint8_t value)
     {
+#ifdef DEBUG
+        //if (address == 0xD01A)
+        //{
+        //    std::cout << std::hex << (int)address << ": " << (int)value << std::endl;
+        //}
+        if (address == 0xD020)
+        {
+            //std::cout << (int)(value && 0x0f) << std::endl;
+            const char* msg = 0;
+            if (value == 5 || value == 13) msg = "OK";      // Green
+            else if (value == 2 || value == 10) msg = "KO"; // Red
+            if (msg)
+            {
+                std::cout << std::endl << msg << std::endl;
+            }
+        }
+#endif
         write(endian_16lo8(address), value);
     }
 
