@@ -1,7 +1,7 @@
 /*
  * This file is part of libsidplayfp, a SID player engine.
  *
- * Copyright 2011-2013 Leandro Nini <drfiemost@users.sourceforge.net>
+ * Copyright 2011-2015 Leandro Nini <drfiemost@users.sourceforge.net>
  * Copyright 2007-2010 Antti Lankila
  * Copyright 2000 Simon White
  *
@@ -30,6 +30,7 @@
 #include "sidmemory.h"
 
 #include "Banks/Bank.h"
+#include "Banks/IOBank.h"
 #include "Banks/SystemRAMBank.h"
 #include "Banks/SystemROMBanks.h"
 #include "Banks/ZeroRAMBank.h"
@@ -54,7 +55,7 @@ private:
     Bank* cpuWriteMap[16];
 
     /// IO region handler
-    Bank* ioBank;
+    IOBank* ioBank;
 
     /// Kernal ROM
     KernalRomBank kernalRomBank;
@@ -78,7 +79,7 @@ private:
     event_clock_t getPhi2Time() const { return context.getTime(EVENT_CLOCK_PHI2); }
 
 public:
-    MMU(EventContext *context, Bank* ioBank);
+    MMU(EventContext *context, IOBank* ioBank);
     ~MMU () {}
 
     void reset();
