@@ -20,26 +20,28 @@
 
 #include "SidTuneTools.h"
 
+#include "SidTuneCfg.h"
+
 // Return pointer to file name position in complete path.
 size_t SidTuneTools::fileNameWithoutPath(const char* s)
 {
     size_t last_slash_pos = -1;
     const size_t length = strlen(s);
-    for ( size_t pos = 0; pos < length; pos++ )
+    for (size_t pos = 0; pos < length; pos++)
     {
 #if defined(SID_FS_IS_COLON_AND_BACKSLASH_AND_SLASH)
-        if ( s[pos] == ':' || s[pos] == '\\' ||
-             s[pos] == '/' )
+        if (s[pos] == ':' || s[pos] == '\\'
+            || s[pos] == '/')
 #elif defined(SID_FS_IS_COLON_AND_SLASH)
-        if ( s[pos] == ':' || s[pos] == '/' )
+        if (s[pos] == ':' || s[pos] == '/')
 #elif defined(SID_FS_IS_SLASH)
-        if ( s[pos] == '/' )
+        if (s[pos] == '/')
 #elif defined(SID_FS_IS_BACKSLASH)
-        if ( s[pos] == '\\' )
+        if (s[pos] == '\\')
 #elif defined(SID_FS_IS_COLON)
-        if ( s[pos] == ':' )
+        if (s[pos] == ':')
 #else
-#error Missing file/path separator definition.
+#  error Missing file/path separator definition.
 #endif
         {
             last_slash_pos = pos;
@@ -54,7 +56,7 @@ size_t SidTuneTools::slashedFileNameWithoutPath(const char* s)
 {
     size_t last_slash_pos = -1;
     const size_t length = strlen(s);
-    for ( size_t pos = 0; pos < length; pos++ )
+    for (size_t pos = 0; pos < length; pos++)
     {
         if ( s[pos] == '/' )
         {
@@ -69,13 +71,13 @@ size_t SidTuneTools::slashedFileNameWithoutPath(const char* s)
 const char* SidTuneTools::fileExtOfPath(const char* s)
 {
     size_t last_dot_pos = strlen(s);  // assume no dot and append
-    for ( size_t pos = last_dot_pos; pos > 0; pos-- )
+    for (size_t pos = last_dot_pos; pos > 0; pos--)
     {
-        if ( s[pos-1] == '.' )
+        if (s[pos-1] == '.')
         {
             last_dot_pos = pos - 1;
             break;
         }
     }
-    return( &s[last_dot_pos] );
+    return  &s[last_dot_pos];
 }
